{% extends 'utilities/obj_device.html' %}
{% load form_helpers %}

{% block form %}
    <div class="panel panel-default">
        <div class="panel-heading"><strong>Network Tunnels</strong></div>
        <div class="panel-body">
            {% render_field form.device %}
            {% render_field form.name %}
            {% render_field form.value %}
        </div>
    </div>
{% endblock %}
