{% extends 'base.html' %}
{% load buttons %}

{% block content %}
<div class="pull-right noprint">
    {% if permissions.add %}
        {% add_button "plugins:netbox_tunnels:tunnel_creation" %}
        {% import_button "plugins:netbox_tunnels:tunnels_import" %}
    {% endif %}
</div>
<h1>{% block title %}Network Tunnels{% endblock %}</h1>
<div class="row">
	<div class="col-md-9">
        {% include 'utilities/obj_table.html' with bulk_delete_url="plugins:netbox_tunnels:tunnels_bulk_delete" %}
    </div>
	<div class="col-md-3 noprint">
		{% include 'inc/search_panel.html' %}
	</div>
</div>
{% endblock %}
